.pagebody {
    padding: 10px;
}
.pagebody * {
    margin-top: 2px;
    margin-bottom: 2px;
}
.pagebody a[href^="http://"],
.pagebody a[href^="https://"],
.pagebody a[href^="ftp://"],
.pagebody a.external {
    background: url("../graphics/external.png") center right no-repeat;
    padding-right: 13px;
}
.pagebody pre {
    border: 1px dashed #999;
    background: #eee;
    padding: 2px;
}
.pagebody tt {
    background: #eee;
    padding-left: 2px;
    padding-right: 2px;
}
.pagebody h1 {
    border-bottom: 2px solid black;
}
.pagebody h2 {
    border-bottom: 1px solid black;
}
.pagebody h1, .pagebody h2, .pagebody h3, .pagebody h4, .pagebody h5, .pagebody h6 {
    margin: .4em 0 .4em 0;
}
.pagebody p {
    margin-top: 10px;
    margin-bottom: 10px;
}
.pagebody hr {
    margin: .5em 0;
}
.pagebody ol, .pagebody ul, .pagebody li {
    margin-left: 20px;
}
.pagebody dd {
    margin-left: 40px;
}
.pagebody blockquote {
    margin-left: 40px;
}
.pagebody .center {
    text-align: center;
}
