<?php
/**
 * Copyright 2009-2013 Horde LLC (http://www.horde.org/)
 *
 * See the enclosed file COPYING for license information (GPL). If you
 * did not receive this file, see http://www.horde.org/licenses/gpl.
 *
 * @category Horde
 * @license  http://www.horde.org/licenses/gpl GPL
 * @author  Michael J. Rubinsky <mrubinsk@horde.org>
 * @package Wicked
 */

/**
 * Base exception class for Wicked.
 *
 * @category Horde
 * @license  http://www.horde.org/licenses/gpl GPL
 * @author  Michael J. Rubinsky <mrubinsk@horde.org>
 * @package Wicked
 */
class Wicked_Exception extends Horde_Exception_Wrapped
{
}
