<?php

require_once 'Text/Wiki/Parse/Mediawiki/Heading.php';

/**
 * Parsers class as a complement to the Header2 renderer.
 *
 * @package Wicked
 */
class Text_Wiki_Parse_Heading2 extends Text_Wiki_Parse_Heading
{
}
